# cv_compare

Tool to quickly compare the performance of a set of baseline ML methodologies. 

## Getting started

- [Installation](installation.md) - how to install cv_compare
- [Usage](usage.md) - how to use cv_compare
- [API Reference](api.md) - auto-generated API documentation
